@@ -32,7 +32,9 @@
 #include <qjson/serializer.h>
 #include <qjson/qobjecthelper.h>
 
+#include "dbushelper.h"
 #include "filetransferjob.h"
+#include "pluginloader.h"
 
 const QCA::EncryptionAlgorithm NetworkPackage::EncryptionAlgorithm = QCA::EME_PKCS1v15;
 const int NetworkPackage::ProtocolVersion = 5;
@@ -56,8 +58,10 @@ void NetworkPackage::createIdentityPackage(NetworkPackage* np)
     np->mPayloadSize = 0;
     np->set("deviceId", id);
     np->set("deviceName", qgetenv("USER") + "@" + QHostInfo::localHostName());
-    np->set("protocolType", "desktop"); //TODO: Detect laptop, tablet, phone...
+    np->set("deviceType", "desktop"); //TODO: Detect laptop, tablet, phone...
     np->set("protocolVersion",  NetworkPackage::ProtocolVersion);
+    np->set("SupportedIncomingInterfaces", PluginLoader::instance()->incomingInterfaces().join(","));
+    np->set("SupportedOutgoingInterfaces", PluginLoader::instance()->outgoingInterfaces().join(","));
 
     //kDebug(kdeconnect_kded()) << "createIdentityPackage" << np->serialize();
 }
@@ -117,6 +121,14 @@ bool NetworkPackage::unserialize(const QByteArray& a, NetworkPackage* np)
     }
     np->mPayloadTransferInfo = variant["payloadTransferInfo"].toMap(); //Will return an empty qvariantmap if was not present, which is ok
 
+    //Ids containing characters that are not allowed as dbus paths would make app crash
+    if (np->mBody.contains("deviceId"))
+    {
+        QString deviceId = np->get<QString>("deviceId");
+        DbusHelper::filterNonExportableCharacters(deviceId);
+        np->set("deviceId", deviceId);
+    }
+
     return true;
 
 }
