@@ -48,8 +48,9 @@ NotificationsModel::NotificationsModel(QObject* parent)
 
     //Role names for QML
     QHash<int, QByteArray> names = roleNames();
-    names.insert(DbusInterfaceRole, "dbusInterface");
-    names.insert(AppNameModelRole, "appName");
+    names.insert(DbusInterfaceRole,    "dbusInterface");
+    names.insert(AppNameModelRole,     "appName");
+    names.insert(IdModelRole,          "notificationId");
     names.insert(DismissableModelRole, "dismissable");
     setRoleNames(names);
 
@@ -154,7 +155,7 @@ QVariant NotificationsModel::data(const QModelIndex& index, int role) const
 
     NotificationDbusInterface* notification = m_notificationList[index.row()];
 
-    //FIXME: This function gets called lots of times, producing lots of dbus calls. Add a cache.
+    //FIXME: This function gets called lots of times, producing lots of dbus calls. Add a cache?
     switch (role) {
         case IconModelRole:
             return KIcon("device-notifier").pixmap(32, 32);
